﻿/*
   Copyright 2012-2013 Marco De Salvo

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;
using System.IO;

namespace RDFSharp.Model
{

    /// <summary>
    /// RDFSerializer exposes choices to read and write RDF data in supported syntaxes.
    /// </summary>
    public static class RDFSerializer {

        #region Methods
        /// <summary>
        /// Writes the given graph to the given file in the given RDF syntax. 
        /// </summary>
        public static void WriteRDF(RDFModelEnums.RDFSyntaxes rdfSyntax, RDFGraph graph, String filepath) {
            if (graph != null) {
                if (filepath != null && filepath.Trim() != String.Empty) {
                    switch(rdfSyntax) {
                        case RDFModelEnums.RDFSyntaxes.NTriples:
                            NTriples.Serialize(graph, filepath);
                            break;
                        case RDFModelEnums.RDFSyntaxes.RdfXml:
                            RdfXml.Serialize(graph, filepath);
                            break;
                        case RDFModelEnums.RDFSyntaxes.TriX:
                            TriX.Serialize(graph, filepath);
                            break;
                        case RDFModelEnums.RDFSyntaxes.Turtle:
                            Turtle.Serialize(graph, filepath);
                            break;
                        default:
                            throw new RDFModelException("Cannot write RDF file because " + rdfSyntax.ToString() + " writing is not supported.");
                    }
                }
                else {
                    throw new RDFModelException("Cannot write RDF file because given \"filepath\" parameter is null or empty.");
                }
            }
            else {
                throw new RDFModelException("Cannot write RDF file because given \"graph\" parameter is null.");
            }
        }

        /// <summary>
        /// Reads the given file in the given RDF syntax to a graph. 
        /// </summary>
        public static RDFGraph ReadRDF(RDFModelEnums.RDFSyntaxes rdfSyntax, String filepath) {
            if (filepath != null && filepath.Trim() != String.Empty) {
                if (File.Exists(filepath.Trim())) {
                    switch(rdfSyntax) {
                        case RDFModelEnums.RDFSyntaxes.NTriples:
                            return NTriples.Deserialize(filepath);
                        case RDFModelEnums.RDFSyntaxes.RdfXml:
                            return RdfXml.Deserialize(filepath);
                        case RDFModelEnums.RDFSyntaxes.TriX:
                            return TriX.Deserialize(filepath);
                        default:
                            throw new RDFModelException("Cannot read RDF file because " + rdfSyntax.ToString() + " reading is not supported.");
                    }
                }
                else {
                    throw new RDFModelException("Cannot read RDF file because given \"filepath\" parameter does not indicate an existing file.");
                }
            }
            else {
                throw new RDFModelException("Cannot read RDF file because given \"filepath\" parameter is null or empty.");
            }
        }
        #endregion
        
    }

}