﻿/*
   Copyright 2012-2013 Marco De Salvo

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

using System;

namespace RDFSharp.Model
{

    /// <summary>
    /// RDFVocabulary is an helper for handy usage of supported RDF vocabularies.
    /// </summary>
    public static class RDFVocabulary {

        #region Basic

        #region RDF
        /// <summary>
        /// RDF represents the RDF vocabulary.
        /// </summary>
        public static class RDF {

            #region Properties
            /// <summary>
            /// rdf
            /// </summary>
            public static String PREFIX {
                get { return "rdf"; }
            }

            /// <summary>
            /// xmlns:rdf
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/1999/02/22-rdf-syntax-ns#"; }
            }

            /// <summary>
            /// rdf:Bag
            /// </summary>
            public static RDFResource BAG {
                get { return new RDFResource(RDF.BASE_URI + "Bag"); }
            }

            /// <summary>
            /// rdf:Seq
            /// </summary>
            public static RDFResource SEQ  {
                get { return new RDFResource(RDF.BASE_URI + "Seq"); }
            }

            /// <summary>
            /// rdf:Alt
            /// </summary>
            public static RDFResource ALT {
                get { return new RDFResource(RDF.BASE_URI + "Alt"); }
            }

            /// <summary>
            /// rdf:Statement
            /// </summary>
            public static RDFResource STATEMENT {
                get { return new RDFResource(RDF.BASE_URI + "Statement"); }
            }

            /// <summary>
            /// rdf:Property
            /// </summary>
            public static RDFResource PROPERTY {
                get { return new RDFResource(RDF.BASE_URI + "Property"); }
            }

            /// <summary>
            /// rdf:XMLLiteral
            /// </summary>
            public static RDFResource XML_LITERAL {
                get { return new RDFResource(RDF.BASE_URI + "XMLLiteral"); }
            }

            /// <summary>
            /// rdf:List
            /// </summary>
            public static RDFResource LIST {
                get { return new RDFResource(RDF.BASE_URI + "List"); }
            }

            /// <summary>
            /// rdf:nil
            /// </summary>
            public static RDFResource NIL {
                get { return new RDFResource(RDF.BASE_URI + "nil"); }
            }

            /// <summary>
            /// rdf:li
            /// </summary>
            public static RDFResource LI {
                get { return new RDFResource(RDF.BASE_URI + "li"); }
            }

            /// <summary>
            /// rdf:subject
            /// </summary>
            public static RDFResource SUBJECT {
                get { return new RDFResource(RDF.BASE_URI + "subject"); }
            }

            /// <summary>
            /// rdf:predicate
            /// </summary>
            public static RDFResource PREDICATE {
                get { return new RDFResource(RDF.BASE_URI + "predicate"); }
            }

            /// <summary>
            /// rdf:object
            /// </summary>
            public static RDFResource OBJECT {
                get { return new RDFResource(RDF.BASE_URI + "object"); }
            }

            /// <summary>
            /// rdf:type
            /// </summary>
            public static RDFResource TYPE {
                get { return new RDFResource(RDF.BASE_URI + "type"); }
            }

            /// <summary>
            /// rdf:value
            /// </summary>
            public static RDFResource VALUE {
                get { return new RDFResource(RDF.BASE_URI + "value"); }
            }

            /// <summary>
            /// rdf:first
            /// </summary>
            public static RDFResource FIRST {
                get { return new RDFResource(RDF.BASE_URI + "first"); }
            }

            /// <summary>
            /// rdf:rest
            /// </summary>
            public static RDFResource REST {
                get { return new RDFResource(RDF.BASE_URI + "rest"); }
            }
            #endregion

        }
        #endregion

        #region RDFS
        /// <summary>
        /// RDFS represents the RDFS vocabulary.
        /// </summary>
        public static class RDFS  {

            #region Properties
            /// <summary>
            /// rdfs
            /// </summary>
            public static String PREFIX {
                get { return "rdfs"; }
            }

            /// <summary>
            /// xmlns:rdfs
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/2000/01/rdf-schema#"; }
            }

            /// <summary>
            /// rdfs:Resource
            /// </summary>
            public static RDFResource RESOURCE {
                get { return new RDFResource(RDFS.BASE_URI + "Resource"); }
            }

            /// <summary>
            /// rdfs:Class
            /// </summary>
            public static RDFResource CLASS {
                get { return new RDFResource(RDFS.BASE_URI + "Class"); }
            }

            /// <summary>
            /// rdfs:Literal
            /// </summary>
            public static RDFResource LITERAL {
                get { return new RDFResource(RDFS.BASE_URI + "Literal"); }
            }

            /// <summary>
            /// rdfs:XMLLiteral
            /// </summary>
            public static RDFResource XML_LITERAL {
                get { return new RDFResource(RDFS.BASE_URI + "XMLLiteral"); }
            }

            /// <summary>
            /// rdfs:Container
            /// </summary>
            public static RDFResource CONTAINER {
                get { return new RDFResource(RDFS.BASE_URI + "Container"); }
            }

            /// <summary>
            /// rdfs:Datatype
            /// </summary>
            public static RDFResource DATATYPE {
                get { return new RDFResource(RDFS.BASE_URI + "Datatype"); }
            }

            /// <summary>
            /// rdfs:ContainerMembershipProperty
            /// </summary>
            public static RDFResource CONTAINER_MEMBERSHIP_PROPERTY {
                get { return new RDFResource(RDFS.BASE_URI + "ContainerMembershipProperty"); }
            }

            /// <summary>
            /// rdfs:range
            /// </summary>
            public static RDFResource RANGE {
                get { return new RDFResource(RDFS.BASE_URI + "range"); }
            }

            /// <summary>
            /// rdfs:domain
            /// </summary>
            public static RDFResource DOMAIN {
                get { return new RDFResource(RDFS.BASE_URI + "domain"); }
            }

            /// <summary>
            /// rdfs:subClassOf
            /// </summary>
            public static RDFResource SUB_CLASS_OF {
                get { return new RDFResource(RDFS.BASE_URI + "subClassOf"); }
            }

            /// <summary>
            /// rdfs:subPropertyOf
            /// </summary>
            public static RDFResource SUB_PROPERTY_OF {
                get { return new RDFResource(RDFS.BASE_URI + "subPropertyOf"); }
            }

            /// <summary>
            /// rdfs:label
            /// </summary>
            public static RDFResource LABEL {
                get { return new RDFResource(RDFS.BASE_URI + "label"); }
            }

            /// <summary>
            /// rdfs:comment
            /// </summary>
            public static RDFResource COMMENT {
                get { return new RDFResource(RDFS.BASE_URI + "comment"); }
            }

            /// <summary>
            /// rdfs:member
            /// </summary>
            public static RDFResource MEMBER {
                get { return new RDFResource(RDFS.BASE_URI + "member"); }
            }

            /// <summary>
            /// rdfs:seeAlso
            /// </summary>
            public static RDFResource SEE_ALSO {
                get { return new RDFResource(RDFS.BASE_URI + "seeAlso"); }
            }

            /// <summary>
            /// rdfs:isDefinedBy
            /// </summary>
            public static RDFResource IS_DEFINED_BY {
                get { return new RDFResource(RDFS.BASE_URI + "isDefinedBy"); }
            }
            #endregion

        }
        #endregion

        #region XSD
        /// <summary>
        /// XSD represents the XSD vocabulary.
        /// </summary>
        public static class XSD {

            #region Properties
            /// <summary>
            /// xsd
            /// </summary>
            public static String PREFIX {
                get { return "xsd"; }
            }

            /// <summary>
            /// xmlns:xsd
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/2001/XMLSchema#"; }
            }

            /// <summary>
            /// xsd:string
            /// </summary>
            public static RDFResource STRING {
                get { return new RDFResource(XSD.BASE_URI + "string"); }
            }

            /// <summary>
            /// xsd:boolean
            /// </summary>
            public static RDFResource BOOLEAN {
                get { return new RDFResource(XSD.BASE_URI + "boolean"); }
            }

            /// <summary>
            /// xsd:decimal
            /// </summary>
            public static RDFResource DECIMAL {
                get { return new RDFResource(XSD.BASE_URI + "decimal"); }
            }

            /// <summary>
            /// xsd:float
            /// </summary>
            public static RDFResource FLOAT {
                get { return new RDFResource(XSD.BASE_URI + "float"); }
            }

            /// <summary>
            /// xsd:double
            /// </summary>
            public static RDFResource DOUBLE {
                get { return new RDFResource(XSD.BASE_URI + "double"); }
            }

            /// <summary>
            /// xsd:positiveInteger
            /// </summary>
            public static RDFResource POSITIVE_INTEGER {
                get { return new RDFResource(XSD.BASE_URI + "positiveInteger"); }
            }

            /// <summary>
            /// xsd:negativeInteger
            /// </summary>
            public static RDFResource NEGATIVE_INTEGER {
                get { return new RDFResource(XSD.BASE_URI + "negativeInteger"); }
            }

            /// <summary>
            /// xsd:nonPositiveInteger
            /// </summary>
            public static RDFResource NON_POSITIVE_INTEGER {
                get { return new RDFResource(XSD.BASE_URI + "nonPositiveInteger"); }
            }

            /// <summary>
            /// xsd:nonNegativeInteger
            /// </summary>
            public static RDFResource NON_NEGATIVE_INTEGER {
                get { return new RDFResource(XSD.BASE_URI + "nonNegativeInteger"); }
            }

            /// <summary>
            /// xsd:integer
            /// </summary>
            public static RDFResource INTEGER {
                get { return new RDFResource(XSD.BASE_URI + "integer"); }
            }

            /// <summary>
            /// xsd:long
            /// </summary>
            public static RDFResource LONG {
                get { return new RDFResource(XSD.BASE_URI + "long"); }
            }

            /// <summary>
            /// xsd:unsignedLong
            /// </summary>
            public static RDFResource UNSIGNED_LONG {
                get { return new RDFResource(XSD.BASE_URI + "unsignedLong"); }
            }

            /// <summary>
            /// xsd:int
            /// </summary>
            public static RDFResource INT {
                get { return new RDFResource(XSD.BASE_URI + "int"); }
            }

            /// <summary>
            /// xsd:unsignedInt
            /// </summary>
            public static RDFResource UNSIGNED_INT {
                get { return new RDFResource(XSD.BASE_URI + "unsignedInt"); }
            }

            /// <summary>
            /// xsd:short
            /// </summary>
            public static RDFResource SHORT {
                get { return new RDFResource(XSD.BASE_URI + "short"); }
            }

            /// <summary>
            /// xsd:unsignedShort
            /// </summary>
            public static RDFResource UNSIGNED_SHORT {
                get { return new RDFResource(XSD.BASE_URI + "unsignedShort"); }
            }

            /// <summary>
            /// xsd:byte
            /// </summary>
            public static RDFResource BYTE {
                get { return new RDFResource(XSD.BASE_URI + "byte"); }
            }

            /// <summary>
            /// xsd:unsignedByte
            /// </summary>
            public static RDFResource UNSIGNED_BYTE {
                get { return new RDFResource(XSD.BASE_URI + "unsignedByte"); }
            }

            /// <summary>
            /// xsd:duration
            /// </summary>
            public static RDFResource DURATION {
                get { return new RDFResource(XSD.BASE_URI + "duration"); }
            }

            /// <summary>
            /// xsd:dateTime
            /// </summary>
            public static RDFResource DATETIME {
                get { return new RDFResource(XSD.BASE_URI + "dateTime"); }
            }

            /// <summary>
            /// xsd:time
            /// </summary>
            public static RDFResource TIME {
                get { return new RDFResource(XSD.BASE_URI + "time"); }
            }

            /// <summary>
            /// xsd:date
            /// </summary>
            public static RDFResource DATE {
                get { return new RDFResource(XSD.BASE_URI + "date"); }
            }

            /// <summary>
            /// xsd:gYearMonth
            /// </summary>
            public static RDFResource G_YEAR_MONTH {
                get { return new RDFResource(XSD.BASE_URI + "gYearMonth"); }
            }

            /// <summary>
            /// xsd:gYear
            /// </summary>
            public static RDFResource G_YEAR {
                get { return new RDFResource(XSD.BASE_URI + "gYear"); }
            }

            /// <summary>
            /// xsd:gMonth
            /// </summary>
            public static RDFResource G_MONTH {
                get { return new RDFResource(XSD.BASE_URI + "gMonth"); }
            }

            /// <summary>
            /// xsd:gMonthDay
            /// </summary>
            public static RDFResource G_MONTH_DAY {
                get { return new RDFResource(XSD.BASE_URI + "gMonthDay"); }
            }

            /// <summary>
            /// xsd:gDay
            /// </summary>
            public static RDFResource G_DAY {
                get { return new RDFResource(XSD.BASE_URI + "gDay"); }
            }

            /// <summary>
            /// xsd:hexBinary
            /// </summary>
            public static RDFResource HEX_BINARY {
                get { return new RDFResource(XSD.BASE_URI + "hexBinary"); }
            }

            /// <summary>
            /// xsd:base64Binary
            /// </summary>
            public static RDFResource BASE64_BINARY {
                get { return new RDFResource(XSD.BASE_URI + "base64Binary"); }
            }

            /// <summary>
            /// xsd:anyURI
            /// </summary>
            public static RDFResource ANY_URI {
                get { return new RDFResource(XSD.BASE_URI + "anyURI"); }
            }

            /// <summary>
            /// xsd:QName
            /// </summary>
            public static RDFResource QNAME {
                get { return new RDFResource(XSD.BASE_URI + "QName"); }
            }

            /// <summary>
            /// xsd:NOTATION
            /// </summary>
            public static RDFResource NOTATION {
                get { return new RDFResource(XSD.BASE_URI + "NOTATION"); }
            }

            /// <summary>
            /// xsd:language
            /// </summary>
            public static RDFResource LANGUAGE {
                get { return new RDFResource(XSD.BASE_URI + "language"); }
            }

            /// <summary>
            /// xsd:normalizedString
            /// </summary>
            public static RDFResource NORMALIZED_STRING {
                get { return new RDFResource(XSD.BASE_URI + "normalizedString"); }
            }

            /// <summary>
            /// xsd:token
            /// </summary>
            public static RDFResource TOKEN {
                get { return new RDFResource(XSD.BASE_URI + "token"); }
            }

            /// <summary>
            /// xsd:NMToken
            /// </summary>
            public static RDFResource NMTOKEN {
                get { return new RDFResource(XSD.BASE_URI + "NMToken"); }
            }

            /// <summary>
            /// xsd:Name
            /// </summary>
            public static RDFResource NAME {
                get { return new RDFResource(XSD.BASE_URI + "Name"); }
            }

            /// <summary>
            /// xsd:NCName
            /// </summary>
            public static RDFResource NCNAME {
                get { return new RDFResource(XSD.BASE_URI + "NCName"); }
            }
            #endregion

        }
        #endregion

        #region OWL
        /// <summary>
        /// OWL represents the OWL vocabulary.
        /// </summary>
        public static class OWL {

            #region Properties
            /// <summary>
            /// owl
            /// </summary>
            public static String PREFIX {
                get { return "owl"; }
            }

            /// <summary>
            /// xmlns:owl
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/2002/07/owl#"; }
            }

            /// <summary>
            /// owl:Ontology
            /// </summary>
            public static RDFResource ONTOLOGY {
                get { return new RDFResource(OWL.BASE_URI + "Ontology"); }
            }

            /// <summary>
            /// owl:Class
            /// </summary>
            public static RDFResource CLASS {
                get { return new RDFResource(OWL.BASE_URI + "Class"); }
            }

            /// <summary>
            /// owl:Individual
            /// </summary>
            public static RDFResource INDIVIDUAL {
                get { return new RDFResource(OWL.BASE_URI + "Individual"); }
            }

            /// <summary>
            /// owl:Thing
            /// </summary>
            public static RDFResource THING {
                get { return new RDFResource(OWL.BASE_URI + "Thing"); }
            }

            /// <summary>
            /// owl:Nothing
            /// </summary>
            public static RDFResource NOTHING {
                get { return new RDFResource(OWL.BASE_URI + "Nothing"); }
            }

            /// <summary>
            /// owl:inverseOf
            /// </summary>
            public static RDFResource INVERSE_OF {
                get { return new RDFResource(OWL.BASE_URI + "inverseOf"); }
            }

            /// <summary>
            /// owl:TransitiveProperty
            /// </summary>
            public static RDFResource TRANSITIVE_PROPERTY {
                get { return new RDFResource(OWL.BASE_URI + "TransitiveProperty"); }
            }

            /// <summary>
            /// owl:SymmetricProperty
            /// </summary>
            public static RDFResource SYMMETRIC_PROPERTY {
                get { return new RDFResource(OWL.BASE_URI + "SymmetricProperty"); }
            }

            /// <summary>
            /// owl:FunctionalProperty
            /// </summary>
            public static RDFResource FUNCTIONAL_PROPERTY {
                get { return new RDFResource(OWL.BASE_URI + "FunctionalProperty"); }
            }

            /// <summary>
            /// owl:InverseFunctionalProperty
            /// </summary>
            public static RDFResource INVERSE_FUNCTIONAL_PROPERTY {
                get { return new RDFResource(OWL.BASE_URI + "InverseFunctionalProperty"); }
            }

            /// <summary>
            /// owl:allValuesFrom
            /// </summary>
            public static RDFResource ALL_VALUES_FROM {
                get { return new RDFResource(OWL.BASE_URI + "allValuesFrom"); }
            }

            /// <summary>
            /// owl:someValuesFrom
            /// </summary>
            public static RDFResource SOME_VALUES_FROM {
                get { return new RDFResource(OWL.BASE_URI + "someValuesFrom"); }
            }

            /// <summary>
            /// owl:minCardinality
            /// </summary>
            public static RDFResource MIN_CARDINALITY {
                get { return new RDFResource(OWL.BASE_URI + "minCardinality"); }
            }

            /// <summary>
            /// owl:maxCardinality
            /// </summary>
            public static RDFResource MAX_CARDINALITY {
                get { return new RDFResource(OWL.BASE_URI + "maxCardinality"); }
            }

            /// <summary>
            /// owl:cardinality
            /// </summary>
            public static RDFResource CARDINALITY {
                get { return new RDFResource(OWL.BASE_URI + "cardinality"); }
            }

            /// <summary>
            /// owl:sameAs
            /// </summary>
            public static RDFResource SAME_AS {
                get { return new RDFResource(OWL.BASE_URI + "sameAs"); }
            }
            #endregion

        }
        #endregion

        #region XML
        /// <summary>
        /// XML represents the XML vocabulary.
        /// </summary>
        public static class XML {

            #region Properties
            /// <summary>
            /// xml
            /// </summary>
            public static String PREFIX {
                get { return "xml"; }
            }

            /// <summary>
            /// xmlns:xml
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/XML/1998/namespace#"; }
            }

            /// <summary>
            /// xml:lang
            /// </summary>
            public static RDFResource LANG {
                get { return new RDFResource(XML.BASE_URI + "lang"); }
            }

            /// <summary>
            /// xml:base
            /// </summary>
            public static RDFResource BASE {
                get { return new RDFResource(XML.BASE_URI + "base"); }
            }
            #endregion

        }
        #endregion

        #endregion

        #region Extended

        #region DC
        /// <summary>
        /// DC represents the Dublin Core vocabulary.
        /// </summary>
        public static class DC {

            #region Properties
            /// <summary>
            /// dc
            /// </summary>
            public static String PREFIX {
                get { return "dc"; }
            }

            /// <summary>
            /// xmlns:dc
            /// </summary>
            public static String BASE_URI {
                get { return "http://purl.org/dc/elements/1.1/"; }
            }

            /// <summary>
            /// dc:contributor
            /// </summary>
            public static RDFResource CONTRIBUTOR {
                get { return new RDFResource(DC.BASE_URI + "contributor"); }
            }

            /// <summary>
            /// dc:coverage
            /// </summary>
            public static RDFResource COVERAGE {
                get { return new RDFResource(DC.BASE_URI + "coverage"); }
            }

            /// <summary>
            /// dc:creator
            /// </summary>
            public static RDFResource CREATOR {
                get { return new RDFResource(DC.BASE_URI + "creator"); }
            }

            /// <summary>
            /// dc:date
            /// </summary>
            public static RDFResource DATE {
                get { return new RDFResource(DC.BASE_URI + "date"); }
            }

            /// <summary>
            /// dc:description
            /// </summary>
            public static RDFResource DESCRIPTION {
                get { return new RDFResource(DC.BASE_URI + "description"); }
            }

            /// <summary>
            /// dc:format
            /// </summary>
            public static RDFResource FORMAT {
                get { return new RDFResource(DC.BASE_URI + "format"); }
            }

            /// <summary>
            /// dc:identifier
            /// </summary>
            public static RDFResource IDENTIFIER {
                get { return new RDFResource(DC.BASE_URI + "identifier"); }
            }

            /// <summary>
            /// dc:language
            /// </summary>
            public static RDFResource LANGUAGE {
                get { return new RDFResource(DC.BASE_URI + "language"); }
            }

            /// <summary>
            /// dc:publisher
            /// </summary>
            public static RDFResource PUBLISHER {
                get { return new RDFResource(DC.BASE_URI + "publisher"); }
            }

            /// <summary>
            /// dc:relation
            /// </summary>
            public static RDFResource RELATION {
                get { return new RDFResource(DC.BASE_URI + "relation"); }
            }

            /// <summary>
            /// dc:rights
            /// </summary>
            public static RDFResource RIGHTS {
                get { return new RDFResource(DC.BASE_URI + "rights"); }
            }

            /// <summary>
            /// dc:source
            /// </summary>
            public static RDFResource SOURCE {
                get { return new RDFResource(DC.BASE_URI + "source"); }
            }

            /// <summary>
            /// dc:subject
            /// </summary>
            public static RDFResource SUBJECT {
                get { return new RDFResource(DC.BASE_URI + "subject"); }
            }

            /// <summary>
            /// dc:title
            /// </summary>
            public static RDFResource TITLE {
                get { return new RDFResource(DC.BASE_URI + "title"); }
            }

            /// <summary>
            /// dc:type
            /// </summary>
            public static RDFResource TYPE {
                get { return new RDFResource(DC.BASE_URI + "type"); }
            }
            #endregion

        }
        #endregion

        #region FOAF
        /// <summary>
        /// FOAF represents the Friend-of-a-Friend vocabulary.
        /// </summary>
        public static class FOAF {

            #region Properties
            /// <summary>
            /// foaf
            /// </summary>
            public static String PREFIX {
                get { return "foaf"; }
            }

            /// <summary>
            /// xmlns:foaf
            /// </summary>
            public static String BASE_URI {
                get { return "http://xmlns.com/foaf/0.1/"; }
            }

            /// <summary>
            /// foaf:Agent
            /// </summary>
            public static RDFResource AGENT {
                get { return new RDFResource(FOAF.BASE_URI + "Agent"); }
            }

            /// <summary>
            /// foaf:Person
            /// </summary>
            public static RDFResource PERSON {
                get { return new RDFResource(FOAF.BASE_URI + "Person"); }
            }

            /// <summary>
            /// foaf:name
            /// </summary>
            public static RDFResource NAME {
                get { return new RDFResource(FOAF.BASE_URI + "name"); }
            }

            /// <summary>
            /// foaf:title
            /// </summary>
            public static RDFResource TITLE {
                get { return new RDFResource(FOAF.BASE_URI + "title"); }
            }

            /// <summary>
            /// foaf:img
            /// </summary>
            public static RDFResource IMG {
                get { return new RDFResource(FOAF.BASE_URI + "img"); }
            }

            /// <summary>
            /// foaf:depiction
            /// </summary>
            public static RDFResource DEPICTION {
                get { return new RDFResource(FOAF.BASE_URI + "depiction"); }
            }

            /// <summary>
            /// foaf:depicts
            /// </summary>
            public static RDFResource DEPICTS {
                get { return new RDFResource(FOAF.BASE_URI + "depicts"); }
            }

            /// <summary>
            /// foaf:familyName
            /// </summary>
            public static RDFResource FAMILY_NAME {
                get { return new RDFResource(FOAF.BASE_URI + "familyName"); }
            }

            /// <summary>
            /// foaf:givenName
            /// </summary>
            public static RDFResource GIVEN_NAME {
                get { return new RDFResource(FOAF.BASE_URI + "givenName"); }
            }

            /// <summary>
            /// foaf:knows
            /// </summary>
            public static RDFResource KNOWS {
                get { return new RDFResource(FOAF.BASE_URI + "knows"); }
            }

            /// <summary>
            /// foaf:based_near
            /// </summary>
            public static RDFResource BASED_NEAR {
                get { return new RDFResource(FOAF.BASE_URI + "based_near"); }
            }

            /// <summary>
            /// foaf:age
            /// </summary>
            public static RDFResource AGE {
                get { return new RDFResource(FOAF.BASE_URI + "age"); }
            }

            /// <summary>
            /// foaf:made
            /// </summary>
            public static RDFResource MADE {
                get { return new RDFResource(FOAF.BASE_URI + "made"); }
            }

            /// <summary>
            /// foaf:maker
            /// </summary>
            public static RDFResource MAKER {
                get { return new RDFResource(FOAF.BASE_URI + "maker"); }
            }

            /// <summary>
            /// foaf:primaryTopic
            /// </summary>
            public static RDFResource PRIMARY_TOPIC {
                get { return new RDFResource(FOAF.BASE_URI + "primaryTopic"); }
            }

            /// <summary>
            /// foaf:isPrimaryTopicOf
            /// </summary>
            public static RDFResource IS_PRIMARY_TOPIC_OF {
                get { return new RDFResource(FOAF.BASE_URI + "isPrimaryTopicOf"); }
            }

            /// <summary>
            /// foaf:Project
            /// </summary>
            public static RDFResource PROJECT {
                get { return new RDFResource(FOAF.BASE_URI + "Project"); }
            }

            /// <summary>
            /// foaf:Organization
            /// </summary>
            public static RDFResource ORGANIZATION {
                get { return new RDFResource(FOAF.BASE_URI + "Organization"); }
            }

            /// <summary>
            /// foaf:Group
            /// </summary>
            public static RDFResource GROUP {
                get { return new RDFResource(FOAF.BASE_URI + "Group"); }
            }

            /// <summary>
            /// foaf:Document
            /// </summary>
            public static RDFResource DOCUMENT {
                get { return new RDFResource(FOAF.BASE_URI + "Document"); }
            }

            /// <summary>
            /// foaf:Image
            /// </summary>
            public static RDFResource IMAGE {
                get { return new RDFResource(FOAF.BASE_URI + "Image"); }
            }

            /// <summary>
            /// foaf:member
            /// </summary>
            public static RDFResource MEMBER {
                get { return new RDFResource(FOAF.BASE_URI + "member"); }
            }
			
			/// <summary>
            /// foaf:focus
            /// </summary>
            public static RDFResource FOCUS {
                get { return new RDFResource(FOAF.BASE_URI + "focus"); }
            }
			
			/// <summary>
            /// foaf:nick
            /// </summary>
            public static RDFResource NICK {
                get { return new RDFResource(FOAF.BASE_URI + "nick"); }
            }
			
			/// <summary>
            /// foaf:mbox
            /// </summary>
            public static RDFResource MBOX {
                get { return new RDFResource(FOAF.BASE_URI + "mbox"); }
            }
			
			/// <summary>
            /// foaf:homepage
            /// </summary>
            public static RDFResource HOMEPAGE {
                get { return new RDFResource(FOAF.BASE_URI + "homepage"); }
            }
			
			/// <summary>
            /// foaf:weblog
            /// </summary>
            public static RDFResource WEBLOG {
                get { return new RDFResource(FOAF.BASE_URI + "weblog"); }
            }
			
			/// <summary>
            /// foaf:openid
            /// </summary>
            public static RDFResource OPEN_ID {
                get { return new RDFResource(FOAF.BASE_URI + "openid"); }
            }
			
			/// <summary>
            /// foaf:jabberID
            /// </summary>
            public static RDFResource JABBER_ID {
                get { return new RDFResource(FOAF.BASE_URI + "jabberID"); }
            }
			
			/// <summary>
            /// foaf:mbox_sha1sum
            /// </summary>
            public static RDFResource MBOX_SHA1SUM {
                get { return new RDFResource(FOAF.BASE_URI + "mbox_sha1sum"); }
            }
			
			/// <summary>
            /// foaf:interest
            /// </summary>
            public static RDFResource INTEREST {
                get { return new RDFResource(FOAF.BASE_URI + "interest"); }
            }
			
			/// <summary>
            /// foaf:topic_interest
            /// </summary>
            public static RDFResource TOPIC_INTEREST {
                get { return new RDFResource(FOAF.BASE_URI + "topic_interest"); }
            }
			
			/// <summary>
            /// foaf:topic
            /// </summary>
            public static RDFResource TOPIC {
                get { return new RDFResource(FOAF.BASE_URI + "topic"); }
            }
			
			/// <summary>
            /// foaf:page
            /// </summary>
            public static RDFResource PAGE {
                get { return new RDFResource(FOAF.BASE_URI + "page"); }
            }
			
			/// <summary>
            /// foaf:workplaceHomepage
            /// </summary>
            public static RDFResource WORKPLACE_HOMEPAGE {
                get { return new RDFResource(FOAF.BASE_URI + "workplaceHomepage"); }
            }
			
			/// <summary>
            /// foaf:workinfoHomepage
            /// </summary>
            public static RDFResource WORKINFO_HOMEPAGE {
                get { return new RDFResource(FOAF.BASE_URI + "workinfoHomepage"); }
            }
			
			/// <summary>
            /// foaf:schoolHomepage
            /// </summary>
            public static RDFResource SCHOOL_HOMEPAGE {
                get { return new RDFResource(FOAF.BASE_URI + "schoolHomepage"); }
            }
			
			/// <summary>
            /// foaf:publications
            /// </summary>
            public static RDFResource PUBLICATIONS {
                get { return new RDFResource(FOAF.BASE_URI + "publications"); }
            }
			
			/// <summary>
            /// foaf:currentProject
            /// </summary>
            public static RDFResource CURRENT_PROJECT {
                get { return new RDFResource(FOAF.BASE_URI + "currentProject"); }
            }
			
			/// <summary>
            /// foaf:pastProject
            /// </summary>
            public static RDFResource PAST_PROJECT {
                get { return new RDFResource(FOAF.BASE_URI + "pastProject"); }
            }
			
			/// <summary>
            /// foaf:account
            /// </summary>
            public static RDFResource ACCOUNT {
                get { return new RDFResource(FOAF.BASE_URI + "account"); }
            }
			
			/// <summary>
            /// foaf:OnlineAccount
            /// </summary>
            public static RDFResource ONLINE_ACCOUNT {
                get { return new RDFResource(FOAF.BASE_URI + "OnlineAccount"); }
            }
			
			/// <summary>
            /// foaf:accountName
            /// </summary>
            public static RDFResource ACCOUNT_NAME {
                get { return new RDFResource(FOAF.BASE_URI + "accountName"); }
            }
			
			/// <summary>
            /// foaf:accountServiceHomepage
            /// </summary>
            public static RDFResource ACCOUNT_SERVICE_HOMEPAGE {
                get { return new RDFResource(FOAF.BASE_URI + "accountServiceHomepage"); }
            }
			
			/// <summary>
            /// foaf:PersonalProfileDocument
            /// </summary>
            public static RDFResource PERSONAL_PROFILE_DOCUMENT {
                get { return new RDFResource(FOAF.BASE_URI + "PersonalProfileDocument"); }
            }
			
			/// <summary>
            /// foaf:tipjar
            /// </summary>
            public static RDFResource TIPJAR {
                get { return new RDFResource(FOAF.BASE_URI + "tipjar"); }
            }
			
			/// <summary>
            /// foaf:sha1
            /// </summary>
            public static RDFResource SHA1 {
                get { return new RDFResource(FOAF.BASE_URI + "sha1"); }
            }
			
			/// <summary>
            /// foaf:thumbnail
            /// </summary>
            public static RDFResource THUMBNAIL {
                get { return new RDFResource(FOAF.BASE_URI + "thumbnail"); }
            }
			
			/// <summary>
            /// foaf:logo
            /// </summary>
            public static RDFResource LOGO {
                get { return new RDFResource(FOAF.BASE_URI + "logo"); }
            }
			
			/// <summary>
            /// foaf:phone
            /// </summary>
            public static RDFResource PHONE {
                get { return new RDFResource(FOAF.BASE_URI + "phone"); }
            }
			
			/// <summary>
            /// foaf:status
            /// </summary>
            public static RDFResource STATUS {
                get { return new RDFResource(FOAF.BASE_URI + "status"); }
            }
			
			/// <summary>
            /// foaf:gender
            /// </summary>
            public static RDFResource GENDER {
                get { return new RDFResource(FOAF.BASE_URI + "gender"); }
            }
			
			/// <summary>
            /// foaf:birthday
            /// </summary>
            public static RDFResource BIRTHDAY {
                get { return new RDFResource(FOAF.BASE_URI + "birthday"); }
            }
            #endregion

        }
        #endregion

        #region GEO
        /// <summary>
        /// GEO represents the W3C GEO vocabulary.
        /// </summary>
        public static class GEO {

            #region Properties
            /// <summary>
            /// geo
            /// </summary>
            public static String PREFIX {
                get { return "geo"; }
            }

            /// <summary>
            /// xmlns:geo
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/2003/01/geo/wgs84_pos#"; }
            }

            /// <summary>
            /// geo:lat
            /// </summary>
            public static RDFResource LAT {
                get { return new RDFResource(GEO.BASE_URI + "lat"); }
            }

            /// <summary>
            /// geo:long
            /// </summary>
            public static RDFResource LONG {
                get { return new RDFResource(GEO.BASE_URI + "long"); }
            }

            /// <summary>
            /// geo:lat_long
            /// </summary>
            public static RDFResource LAT_LONG {
                get { return new RDFResource(GEO.BASE_URI + "lat_long"); }
            }

            /// <summary>
            /// geo:alt
            /// </summary>
            public static RDFResource ALT {
                get { return new RDFResource(GEO.BASE_URI + "alt"); }
            }

            /// <summary>
            /// geo:Point
            /// </summary>
            public static RDFResource POINT {
                get { return new RDFResource(GEO.BASE_URI + "Point"); }
            }

            /// <summary>
            /// geo:SpatialThing
            /// </summary>
            public static RDFResource SPATIAL_THING {
                get { return new RDFResource(GEO.BASE_URI + "SpatialThing"); }
            }

            /// <summary>
            /// geo:location
            /// </summary>
            public static RDFResource LOCATION {
                get { return new RDFResource(GEO.BASE_URI + "location"); }
            }
            #endregion

        }
        #endregion

        #region SKOS
        /// <summary>
        /// SKOS represents the W3C SKOS vocabulary.
        /// </summary>
        public static class SKOS {

            #region Properties
            /// <summary>
            /// skos
            /// </summary>
            public static String PREFIX {
                get { return "skos"; }
            }

            /// <summary>
            /// xmlns:skos
            /// </summary>
            public static String BASE_URI {
                get { return "http://www.w3.org/2004/02/skos/core#"; }
            }

            /// <summary>
            /// skos:Concept
            /// </summary>
            public static RDFResource CONCEPT {
                get { return new RDFResource(SKOS.BASE_URI + "Concept"); }
            }

            /// <summary>
            /// skos:ConceptScheme
            /// </summary>
            public static RDFResource CONCEPT_SCHEME {
                get { return new RDFResource(SKOS.BASE_URI + "ConceptScheme"); }
            }

            /// <summary>
            /// skos:inScheme
            /// </summary>
            public static RDFResource IN_SCHEME {
                get { return new RDFResource(SKOS.BASE_URI + "inScheme"); }
            }

            /// <summary>
            /// skos:hasTopConcept
            /// </summary>
            public static RDFResource HAS_TOP_CONCEPT {
                get { return new RDFResource(SKOS.BASE_URI + "hasTopConcept"); }
            }

            /// <summary>
            /// skos:topConceptOf
            /// </summary>
            public static RDFResource TOP_CONCEPT_OF {
                get { return new RDFResource(SKOS.BASE_URI + "topConceptOf"); }
            }

            /// <summary>
            /// skos:altLabel
            /// </summary>
            public static RDFResource ALT_LABEL {
                get { return new RDFResource(SKOS.BASE_URI + "altLabel"); }
            }

            /// <summary>
            /// skos:hiddenLabel
            /// </summary>
            public static RDFResource HIDDEN_LABEL {
                get { return new RDFResource(SKOS.BASE_URI + "hiddenLabel"); }
            }

            /// <summary>
            /// skos:prefLabel
            /// </summary>
            public static RDFResource PREF_LABEL {
                get { return new RDFResource(SKOS.BASE_URI + "prefLabel"); }
            }

            /// <summary>
            /// skos:notation
            /// </summary>
            public static RDFResource NOTATION {
                get { return new RDFResource(SKOS.BASE_URI + "notation"); }
            }

            /// <summary>
            /// skos:changeNote
            /// </summary>
            public static RDFResource CHANGE_NOTE {
                get { return new RDFResource(SKOS.BASE_URI + "changeNote"); }
            }

            /// <summary>
            /// skos:definition
            /// </summary>
            public static RDFResource DEFINITION {
                get { return new RDFResource(SKOS.BASE_URI + "definition"); }
            }

            /// <summary>
            /// skos:example
            /// </summary>
            public static RDFResource EXAMPLE {
                get { return new RDFResource(SKOS.BASE_URI + "example"); }
            }

            /// <summary>
            /// skos:editorialNote
            /// </summary>
            public static RDFResource EDITORIAL_NOTE {
                get { return new RDFResource(SKOS.BASE_URI + "editorialNote"); }
            }

            /// <summary>
            /// skos:historyNote
            /// </summary>
            public static RDFResource HISTORY_NOTE {
                get { return new RDFResource(SKOS.BASE_URI + "historyNote"); }
            }

            /// <summary>
            /// skos:note
            /// </summary>
            public static RDFResource NOTE {
                get { return new RDFResource(SKOS.BASE_URI + "note"); }
            }

            /// <summary>
            /// skos:scopeNote
            /// </summary>
            public static RDFResource SCOPE_NOTE {
                get { return new RDFResource(SKOS.BASE_URI + "scopeNote"); }
            }

            /// <summary>
            /// skos:broader
            /// </summary>
            public static RDFResource BROADER {
                get { return new RDFResource(SKOS.BASE_URI + "broader"); }
            }

            /// <summary>
            /// skos:broaderTransitive
            /// </summary>
            public static RDFResource BROADER_TRANSITIVE {
                get { return new RDFResource(SKOS.BASE_URI + "broaderTransitive"); }
            }

            /// <summary>
            /// skos:narrower
            /// </summary>
            public static RDFResource NARROWER {
                get { return new RDFResource(SKOS.BASE_URI + "narrower"); }
            }

            /// <summary>
            /// skos:narrowerTransitive
            /// </summary>
            public static RDFResource NARROWER_TRANSITIVE {
                get { return new RDFResource(SKOS.BASE_URI + "narrowerTransitive"); }
            }

            /// <summary>
            /// skos:related
            /// </summary>
            public static RDFResource RELATED {
                get { return new RDFResource(SKOS.BASE_URI + "related"); }
            }

            /// <summary>
            /// skos:semanticRelation
            /// </summary>
            public static RDFResource SEMANTIC_RELATION {
                get { return new RDFResource(SKOS.BASE_URI + "semanticRelation"); }
            }

            /// <summary>
            /// skos:subject
            /// </summary>
            public static RDFResource SUBJECT {
                get { return new RDFResource(SKOS.BASE_URI + "subject"); }
            }

            /// <summary>
            /// skos:Collection
            /// </summary>
            public static RDFResource COLLECTION {
                get { return new RDFResource(SKOS.BASE_URI + "Collection"); }
            }

            /// <summary>
            /// skos:OrderedCollection
            /// </summary>
            public static RDFResource ORDERED_COLLECTION {
                get { return new RDFResource(SKOS.BASE_URI + "OrderedCollection"); }
            }

            /// <summary>
            /// skos:member
            /// </summary>
            public static RDFResource MEMBER {
                get { return new RDFResource(SKOS.BASE_URI + "member"); }
            }

            /// <summary>
            /// skos:memberList
            /// </summary>
            public static RDFResource MEMBER_LIST {
                get { return new RDFResource(SKOS.BASE_URI + "memberList"); }
            }

            /// <summary>
            /// skos:broadMatch
            /// </summary>
            public static RDFResource BROAD_MATCH {
                get { return new RDFResource(SKOS.BASE_URI + "broadMatch"); }
            }

            /// <summary>
            /// skos:closeMatch
            /// </summary>
            public static RDFResource CLOSE_MATCH {
                get { return new RDFResource(SKOS.BASE_URI + "closeMatch"); }
            }

            /// <summary>
            /// skos:narrowMatch
            /// </summary>
            public static RDFResource NARROW_MATCH {
                get { return new RDFResource(SKOS.BASE_URI + "narrowMatch"); }
            }

            /// <summary>
            /// skos:relatedMatch
            /// </summary>
            public static RDFResource RELATED_MATCH {
                get { return new RDFResource(SKOS.BASE_URI + "relatedMatch"); }
            }

            /// <summary>
            /// skos:exactMatch
            /// </summary>
            public static RDFResource EXACT_MATCH {
                get { return new RDFResource(SKOS.BASE_URI + "exactMatch"); }
            }

            /// <summary>
            /// skos:mappingRelation
            /// </summary>
            public static RDFResource MAPPING_RELATION {
                get { return new RDFResource(SKOS.BASE_URI + "mappingRelation"); }
            }
            #endregion

        }
        #endregion
		
		#region DBPEDIA
        /// <summary>
        /// DBPEDIA represents the DBPEDIA vocabulary.
        /// </summary>
        public static class DBPEDIA {

            #region Properties
            /// <summary>
            /// dbpedia
            /// </summary>
            public static String PREFIX {
                get { return "dbpedia"; }
            }

            /// <summary>
            /// xmlns:dbpedia
            /// </summary>
            public static String BASE_URI {
                get { return "http://dbpedia.org/"; }
            }

            /// <summary>
            /// dbpedia:resource
            /// </summary>
            public static RDFResource RESOURCE {
                get { return new RDFResource(DBPEDIA.BASE_URI + "resource"); }
            }

			/// <summary>
            /// dbpedia:class
            /// </summary>
            public static RDFResource CLASS {
                get { return new RDFResource(DBPEDIA.BASE_URI + "class"); }
            }
			
            /// <summary>
            /// dbpedia:ontology
            /// </summary>
            public static RDFResource ONTOLOGY {
                get { return new RDFResource(DBPEDIA.BASE_URI + "ontology"); }
            }
			
			/// <summary>
            /// dbpedia:property
            /// </summary>
            public static RDFResource PROPERTY {
                get { return new RDFResource(DBPEDIA.BASE_URI + "property"); }
            }
            #endregion

        }
        #endregion
		
        #endregion

    }

}